@@ -5,12 +5,15 @@ from mindsdb_native.libs.data_types.data_source import DataSource
 
 
 class MongoDS(DataSource):
-    def _setup(self, collection, query=None, host='localhost', port=27017, user='admin',
-               password='123', database='database'):
-        
+    def _setup(self, collection, query=None, database='database',
+               host='localhost', port=27017, user='admin', password='123'):
+
         if not isinstance(collection, str):
             raise TypeError('collection must be a str')
         
+        self._database_name = database
+        self._collection_name = collection
+
         if query is None:
             query = {}
         else:
@@ -32,3 +35,10 @@ class MongoDS(DataSource):
             col_map[col] = col
 
         return df, col_map
+
+    def name(self):
+        return '{}: {}/{}'.format(
+            self.__class__.__name__,
+            self._database_name,
+            self._collection_name
+        )
\ No newline at end of file
