@@ -174,6 +174,19 @@ def get_identifier_description(data, column_name, data_subtype, other_potential_
 
     foregin_key_type = DATA_SUBTYPES.INT in [*other_potential_subtypes, data_subtype]
 
+    if foregin_key_type:
+        prev = None
+        for x in map(lambda val: int(float(val)), sorted(data)):
+            if prev is None:
+                prev = x
+            else:
+                if (x - prev) != 1:
+                    break
+                else:
+                    prev = x
+        else:
+            return 'Auto-incrementing Identifier'
+
     # Detect UUID
     if foregin_key_type:
         is_uuid = False
